==> integration-tests-jobs-service-springboot-1.15.0.Final-sources.jar: org/acme/travels/AsyncProcess.java <==
package org.acme.travels;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("async")
public class AsyncProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.travels.AsyncModel> {

    public AsyncProcess(org.kie.kogito.app.Application app) {
        this(app, new org.kie.kogito.handlers.HelloService_bye_4_Handler(), new org.kie.kogito.handlers.HelloService_hello_5_Handler());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public AsyncProcess(org.kie.kogito.app.Application app, org.kie.kogito.handlers.HelloService_bye_4_Handler helloService_bye_4_Handler, org.kie.kogito.handlers.HelloService_hello_5_Handler helloService_hello_5_Handler) {
        super(app, java.util.Arrays.asList(helloService_bye_4_Handler, helloService_hello_5_Handler));
        activate();
    }

    public AsyncProcess() {
    }

    @Override()
    public org.acme.travels.AsyncProcessInstance createInstance(org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    @Override()
    public org.acme.travels.AsyncModel createModel() {
        return new org.acme.travels.AsyncModel();
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.travels.AsyncProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), wpi);
    }

    public org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("async");
        factory.variable("name", new ObjectDataType("java.lang.String", org.acme.travels.AsyncProcess.class.getClassLoader()), "customTags", null);
        factory.variable("hello", new ObjectDataType("java.lang.String", org.acme.travels.AsyncProcess.class.getClassLoader()), "customTags", null);
        factory.variable("bye", new ObjectDataType("java.lang.String", org.acme.travels.AsyncProcess.class.getClassLoader()), "customTags", null);
        factory.name("async");
        factory.packageName("org.acme.travels");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode1 = factory.eventNode(1);
        eventNode1.name("complete");
        eventNode1.eventType("complete");
        eventNode1.metaData("UniqueId", "_3A4800AB-2B7A-490E-9D57-44F289795143");
        eventNode1.metaData("elementname", "complete");
        eventNode1.metaData("EventType", "signal");
        eventNode1.metaData("x", 891);
        eventNode1.metaData("width", 56);
        eventNode1.metaData("y", 210);
        eventNode1.metaData("height", 56);
        eventNode1.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode2 = factory.endNode(2);
        endNode2.name("End");
        endNode2.terminate(false);
        endNode2.metaData("UniqueId", "_B9E500DD-6557-4587-B167-B93C0A9366F4");
        endNode2.metaData("x", 998);
        endNode2.metaData("width", 56);
        endNode2.metaData("y", 210);
        endNode2.metaData("height", 56);
        endNode2.done();
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode3 = factory.eventNode(3);
        eventNode3.name("bye");
        eventNode3.eventType("bye");
        eventNode3.metaData("UniqueId", "_7E4B483A-094F-40F5-BCA2-6FB6317A2379");
        eventNode3.metaData("elementname", "bye");
        eventNode3.metaData("EventType", "signal");
        eventNode3.metaData("x", 584);
        eventNode3.metaData("width", 56);
        eventNode3.metaData("y", 210);
        eventNode3.metaData("height", 56);
        eventNode3.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode4 = factory.workItemNode(4);
        workItemNode4.name("bye");
        workItemNode4.workName("org.kie.kogito.HelloService_bye_4_Handler");
        workItemNode4.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode4.workParameter("Operation", "bye");
        workItemNode4.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode4.workParameter("operationImplementationRef", "bye");
        workItemNode4.workParameter("implementation", "Java");
        workItemNode4.inMapping("name", "name");
        workItemNode4.outMapping("response", "bye");
        workItemNode4.done();
        workItemNode4.metaData("UniqueId", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E");
        workItemNode4.metaData("customAsync", "true");
        workItemNode4.metaData("Implementation", "Java");
        workItemNode4.metaData("elementname", "bye");
        workItemNode4.metaData("Type", "Service Task");
        workItemNode4.metaData("OperationRef", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_ServiceOperation");
        workItemNode4.metaData("x", 686);
        workItemNode4.metaData("width", 154);
        workItemNode4.metaData("y", 187);
        workItemNode4.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode5 = factory.workItemNode(5);
        workItemNode5.name("hello");
        workItemNode5.workName("org.kie.kogito.HelloService_hello_5_Handler");
        workItemNode5.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode5.workParameter("Operation", "hello");
        workItemNode5.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode5.workParameter("operationImplementationRef", "hello");
        workItemNode5.workParameter("implementation", "Java");
        workItemNode5.inMapping("name", "name");
        workItemNode5.outMapping("response", "hello");
        workItemNode5.done();
        workItemNode5.metaData("UniqueId", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F");
        workItemNode5.metaData("customAsync", "true");
        workItemNode5.metaData("Implementation", "Java");
        workItemNode5.metaData("elementname", "hello");
        workItemNode5.metaData("Type", "Service Task");
        workItemNode5.metaData("OperationRef", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_ServiceOperation");
        workItemNode5.metaData("x", 368);
        workItemNode5.metaData("width", 154);
        workItemNode5.metaData("y", 187);
        workItemNode5.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode6 = factory.startNode(6);
        startNode6.name("Start");
        startNode6.interrupting(false);
        startNode6.metaData("UniqueId", "_459575F0-71A6-4ECB-A809-AB04213A3EF9");
        startNode6.metaData("x", 232);
        startNode6.metaData("width", 56);
        startNode6.metaData("y", 210);
        startNode6.metaData("height", 56);
        startNode6.done();
        factory.connection(4, 1, "_8E6BB681-019C-4A65-A032-D491576578ED");
        factory.connection(1, 2, "_B16F4B51-57C0-4959-A5EF-461A4A4E8FDE");
        factory.connection(5, 3, "_081637BA-F35A-478C-AD70-72A1BDA1F4D6");
        factory.connection(3, 4, "_7F64F507-4BD6-41E3-8789-D81D0D68D242");
        factory.connection(6, 5, "_D13DA799-0FCC-4E7C-A97A-66943891C7F4");
        factory.validate();
        return factory.getProcess();
    }
}

==> integration-tests-jobs-service-springboot-1.17.0.Final-sources.jar: org/acme/travels/AsyncProcess.java <==
package org.acme.travels;

import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;
import org.jbpm.process.core.datatype.impl.type.StringDataType;

@org.springframework.stereotype.Component("async")
public class AsyncProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.travels.AsyncModel> {

    public AsyncProcess(org.kie.kogito.app.Application app) {
        this(app, new org.kie.kogito.handlers.HelloService_bye_4_Handler(), new org.kie.kogito.handlers.HelloService_hello_5_Handler());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public AsyncProcess(org.kie.kogito.app.Application app, org.kie.kogito.handlers.HelloService_bye_4_Handler helloService_bye_4_Handler, org.kie.kogito.handlers.HelloService_hello_5_Handler helloService_hello_5_Handler) {
        super(app, java.util.Arrays.asList(helloService_bye_4_Handler, helloService_hello_5_Handler));
        activate();
    }

    public AsyncProcess() {
    }

    @Override()
    public org.acme.travels.AsyncProcessInstance createInstance(org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    @Override()
    public org.acme.travels.AsyncModel createModel() {
        return new org.acme.travels.AsyncModel();
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.travels.AsyncProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), wpi);
    }

    public org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("async");
        factory.variable("name", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.variable("hello", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.variable("bye", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.name("async");
        factory.packageName("org.acme.travels");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode1 = factory.eventNode(1);
        eventNode1.name("complete");
        eventNode1.eventType("complete");
        eventNode1.metaData("UniqueId", "_3A4800AB-2B7A-490E-9D57-44F289795143");
        eventNode1.metaData("elementname", "complete");
        eventNode1.metaData("EventType", "signal");
        eventNode1.metaData("x", 891);
        eventNode1.metaData("width", 56);
        eventNode1.metaData("y", 210);
        eventNode1.metaData("height", 56);
        eventNode1.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode2 = factory.endNode(2);
        endNode2.name("End");
        endNode2.terminate(false);
        endNode2.metaData("UniqueId", "_B9E500DD-6557-4587-B167-B93C0A9366F4");
        endNode2.metaData("x", 998);
        endNode2.metaData("width", 56);
        endNode2.metaData("y", 210);
        endNode2.metaData("height", 56);
        endNode2.done();
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode3 = factory.eventNode(3);
        eventNode3.name("bye");
        eventNode3.eventType("bye");
        eventNode3.metaData("UniqueId", "_7E4B483A-094F-40F5-BCA2-6FB6317A2379");
        eventNode3.metaData("elementname", "bye");
        eventNode3.metaData("EventType", "signal");
        eventNode3.metaData("x", 584);
        eventNode3.metaData("width", 56);
        eventNode3.metaData("y", 210);
        eventNode3.metaData("height", 56);
        eventNode3.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode4 = factory.workItemNode(4);
        workItemNode4.name("bye");
        workItemNode4.workName("org.kie.kogito.HelloService_bye_4_Handler");
        workItemNode4.workParameter("NodeName", "bye");
        workItemNode4.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode4.workParameter("Operation", "bye");
        workItemNode4.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode4.workParameter("operationImplementationRef", "bye");
        workItemNode4.workParameter("implementation", "Java");
        workItemNode4.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("name", "name", "java.lang.Object", null)), new org.jbpm.workflow.core.impl.DataDefinition("_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_nameInputX", "name", "String", null), null, null));
        workItemNode4.mapDataOutputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_responseOutputX", "response", "String", null)), new org.jbpm.workflow.core.impl.DataDefinition("bye", "bye", "java.lang.Object", null), null, null));
        workItemNode4.done();
        workItemNode4.metaData("UniqueId", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E");
        workItemNode4.metaData("customAsync", "true");
        workItemNode4.metaData("Implementation", "Java");
        workItemNode4.metaData("elementname", "bye");
        workItemNode4.metaData("Type", "Service Task");
        workItemNode4.metaData("OperationRef", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_ServiceOperation");
        workItemNode4.metaData("x", 686);
        workItemNode4.metaData("width", 154);
        workItemNode4.metaData("y", 187);
        workItemNode4.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode5 = factory.workItemNode(5);
        workItemNode5.name("hello");
        workItemNode5.workName("org.kie.kogito.HelloService_hello_5_Handler");
        workItemNode5.workParameter("NodeName", "hello");
        workItemNode5.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode5.workParameter("Operation", "hello");
        workItemNode5.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode5.workParameter("operationImplementationRef", "hello");
        workItemNode5.workParameter("implementation", "Java");
        workItemNode5.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("name", "name", "java.lang.Object", null)), new org.jbpm.workflow.core.impl.DataDefinition("_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_nameInputX", "name", "String", null), null, null));
        workItemNode5.mapDataOutputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_responseOutputX", "response", "String", null)), new org.jbpm.workflow.core.impl.DataDefinition("hello", "hello", "java.lang.Object", null), null, null));
        workItemNode5.done();
        workItemNode5.metaData("UniqueId", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F");
        workItemNode5.metaData("customAsync", "true");
        workItemNode5.metaData("Implementation", "Java");
        workItemNode5.metaData("elementname", "hello");
        workItemNode5.metaData("Type", "Service Task");
        workItemNode5.metaData("OperationRef", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_ServiceOperation");
        workItemNode5.metaData("x", 368);
        workItemNode5.metaData("width", 154);
        workItemNode5.metaData("y", 187);
        workItemNode5.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode6 = factory.startNode(6);
        startNode6.name("Start");
        startNode6.interrupting(false);
        startNode6.metaData("UniqueId", "_459575F0-71A6-4ECB-A809-AB04213A3EF9");
        startNode6.metaData("x", 232);
        startNode6.metaData("width", 56);
        startNode6.metaData("y", 210);
        startNode6.metaData("height", 56);
        startNode6.done();
        factory.connection(4, 1, "_8E6BB681-019C-4A65-A032-D491576578ED");
        factory.connection(1, 2, "_B16F4B51-57C0-4959-A5EF-461A4A4E8FDE");
        factory.connection(5, 3, "_081637BA-F35A-478C-AD70-72A1BDA1F4D6");
        factory.connection(3, 4, "_7F64F507-4BD6-41E3-8789-D81D0D68D242");
        factory.connection(6, 5, "_D13DA799-0FCC-4E7C-A97A-66943891C7F4");
        factory.validate();
        return factory.getProcess();
    }
}
